@@ -9,14 +9,14 @@ from dataclasses import dataclass
 
 from gevent import sleep as gsleep
 
-from ..context import GrizzlyTask, GrizzlyTasksBase
+from ..context import GrizzlyTask, GrizzlyScenarioBase
 
 @dataclass
 class WaitTask(GrizzlyTask):
     time: float
 
-    def implementation(self) -> Callable[[GrizzlyTasksBase], Any]:
-        def _implementation(parent: GrizzlyTasksBase) -> Any:
+    def implementation(self) -> Callable[[GrizzlyScenarioBase], Any]:
+        def _implementation(parent: GrizzlyScenarioBase) -> Any:
             parent.logger.debug(f'waiting for {self.time} seconds')
             gsleep(self.time)
             parent.logger.debug(f'done waiting for {self.time} seconds')
