@@ -1,5 +1,3 @@
-import logging
-
 from typing import Any, Callable, Dict, Optional, Union, Tuple, Iterable, cast
 from time import monotonic as time, sleep
 from mypy_extensions import VarArg, KwArg
@@ -19,7 +17,6 @@ from . import (
     AsyncMessageResponse,
     AsyncMessageError,
     register,
-    logger,
 )
 
 __all__ = [
@@ -48,9 +45,6 @@ class AsyncServiceBusHandler(AsyncMessageHandler):
         self._receiver_cache = {}
         self._arguments = {}
 
-        # silence uamqp loggers
-        logging.getLogger('uamqp').setLevel(logging.ERROR)
-
     @classmethod
     def get_sender_instance(cls, client: ServiceBusClient, arguments: Dict[str, str]) -> ServiceBusSender:
         endpoint_type = arguments['endpoint_type']
@@ -278,10 +272,10 @@ class AsyncServiceBusHandler(AsyncMessageHandler):
                 for received_message in receiver:
                     message = cast(ServiceBusMessage, received_message)
 
-                    logger.debug(f'{self.worker}: got message id: {message.message_id}')
+                    self.logger.debug(f'got message id: {message.message_id}')
 
                     if expression is None:
-                        logger.debug(f'{self.worker}: completing message id: {message.message_id}')
+                        self.logger.debug(f'completing message id: {message.message_id}')
                         receiver.complete_message(message)
                         break
 
@@ -295,15 +289,15 @@ class AsyncServiceBusHandler(AsyncMessageHandler):
                         try:
                             _, transformed_payload = transform.transform(content_type, payload)
                         except TransformerError as e:
-                            logger.error(f'{self.worker}: {payload}')
+                            self.logger.error(payload)
                             raise AsyncMessageError(e.message)
 
                         values = get_values(transformed_payload)
 
-                        logger.debug(f'{self.worker}: expression={request_arguments["expression"]}, matches={values}, payload={transformed_payload}')
+                        self.logger.debug(f'expression={request_arguments["expression"]}, matches={values}, payload={transformed_payload}')
 
                         if len(values) > 0:
-                            logger.debug(f'{self.worker}: completing message id: {message.message_id}, with expression "{request_arguments["expression"]}"')
+                            self.logger.debug(f'completing message id: {message.message_id}, with expression "{request_arguments["expression"]}"')
                             receiver.complete_message(message)
                             had_error = False
                             break
@@ -312,7 +306,7 @@ class AsyncServiceBusHandler(AsyncMessageHandler):
                     finally:
                         if had_error:
                             if message is not None:
-                                logger.debug(f'{self.worker}: abandoning message id: {message.message_id}, {message._raw_amqp_message.header.delivery_count}')
+                                self.logger.debug(f'abandoning message id: {message.message_id}, {message._raw_amqp_message.header.delivery_count}')
                                 receiver.abandon_message(message)
                                 message = None
 
